<?php
/**
 * @property-read string $EP_MerNo
 * @property-read string $webkey
 * @property-read string $EP_Expires
 * @property-read string $EP_Debug
 */
class eripPayment extends waPayment implements waIPayment
{
    private $order_id;

	private function getEndpointUrl()
    {
        return 'https://ssl.easypay.by/weborder/?EP_Module=shopscript';
    }

	 public function allowedCurrency()
    {
        return array('BYR', 'BYN');
    }

    public function payment($payment_form_data, $order_data, $auto_submit = true)
    {
        $order = waOrder::factory($order_data);

        $view = wa()->getView();
        $view->assign('data', $payment_form_data);
        $view->assign('order', $order_data);
        $view->assign('settings', $this->getSettings());
		
		$EP_Hash = md5 ($this->EP_MerNo . $this->webkey . $order->id . $order->total);

		$form = array();

        $form['EP_Sum']			= $order->total;
        $form['EP_OrderNo']		= $order->id;
        $form['EP_MerNo']		= $this->EP_MerNo;
        $form['EP_Comment']		= "Оплата заказа №".$order->id;
        $form['EP_OrderInfo']	= "Заказ от магазина ".$this->shop;
		$form['EP_Expires']		= $this->EP_Expires;
		$form['EP_Hash']		= $EP_Hash;
        $form['EP_Success_URL']	= $this->getRelayUrl().'?transaction_result=success&merchant_id='.$this->merchant_id.'&app_id='.$this->app_id;
        $form['EP_Cancel_URL']	= $this->getRelayUrl().'?transaction_result=cancel&merchant_id='.$this->merchant_id.'&app_id='.$this->app_id;
		$form['EP_Encoding']	= "utf-8";
		$form['EP_PayType']		= "PT_ERIP";

        $view->assign('form', $form);
        $view->assign('form_url', $this->getEndpointUrl());
        $view->assign('auto_submit', $auto_submit);
        return $view->fetch($this->path.'/templates/payment.html');
    }

	  protected function callbackInit($request)
    {	
		 if(isset($request['order_mer_code'])){
			$this->order_id = trim($request['order_mer_code']);
		 }else{
			$this->order_id = trim($request['EP_OrderNo']);
		 }
		$this->app_id = ifempty($request['app_id'], 'shop');
		$this->merchant_id = ifempty($request['merchant_id']);
       return parent::callbackInit($request);
    }

    protected function callbackHandler($request)
    {
        // приводим данные о транзакции к универсальному виду
        $transaction_data = $this->formalizeData($request);
		$app_payment_method = null;

        $transaction_result = ifempty($request['transaction_result'], 'cancel');

		if($transaction_result == 'notify'){//Нотификация
			$check = $this->verifySign($request);//Проверяем данные и подпись
			if($check){
				$app_payment_method = self::CALLBACK_PAYMENT;
				$transaction_data['state'] = self::STATE_CAPTURED;
				// сохраняем данные транзакции в базу данных
				$transaction_data = $this->saveTransaction($transaction_data, $request);

				// вызываем соответствующий обработчик приложения для каждого из поддерживаемых типов транзакций
				$result = $this->execAppCallback($app_payment_method, $transaction_data);
				// информацию о результате обработки дополнительно пишем в лог плагина
				if (empty($result['error'])) {
					self::log($this->id, array('result' => 'success'));
					$message = 'YES';
				} else {
					$message = $result['error'];
				}
				header("HTTP/1.0 200 OK"); // генерация HTTP-заголовка
			}else{
				header("HTTP/1.0 400 Bad Request");
			}
		}
		
		//Обрабатываем урлы успеха и ошибки оплаты
        if ($transaction_result == 'success' || $transaction_result == 'cancel') {
			$notice = '';//текст сообщения 
			if ($transaction_result == 'success'){
				$notice = '<div style="color:#00a12d; font-size:20px; font-weight:bold;">Счет добавлен в систему ЕРИП для оплаты.</div>
				<div style="color:#00a12d; font-size:20px; font-weight:bold; padding-bottom:15px;">Номер заказа для оплаты: '.$this->order_id.'</div>';
			}elseif($transaction_result == 'cancel'){
				$notice = '<div style="color:#D1001D; font-size:20px; font-weight:bold; padding-bottom:15px;">Ошибка оплаты счета</div>';
			}
			//Передаем в шаблон переменные
            return array(
               'template' => $this->path.'/templates/callback.html',
                'message'  => $message,
				'notice'	=> $notice,
            );
		}
	}
	//Проверка данных и подписи
  private function verifySign($data)
    {
		$result = false;

		$order_mer_code = $data['order_mer_code'];
		$sum            = $data['sum'];
		$mer_no         = $data['mer_no'];
		$card           = $data['card'];
		$purch_date     = $data['purch_date'];
		$web_key        = $this->webkey;
		$notify_sig     = $data['notify_signature'];
		
		$sig = md5 ($order_mer_code . $sum . $mer_no . $card . $purch_date . $web_key);

		//Проверка электронной подписи
		if ($sig == $notify_sig){
			$result = true;
		}
	
        return $result;
    }

    /**
     * Конвертирует исходные данные о транзакции, полученные от платежной системы, в формат, удобный для сохранения в базе данных.
     *
     * @param array $request Исходные данные
     * @return array $transaction_data Форматированные данные
     */
  protected function formalizeData($transaction_raw_data)
    {
        $transaction_data = parent::formalizeData($transaction_raw_data);
		
        $transaction_data['native_id'] = $this->order_id;
        $transaction_data['order_id'] = $this->order_id;

        return $transaction_data;
    }




  
}
